@@ -1,4 +1,4 @@
-/* See LICENSE file for license and copyright information */
+/* SPDX-License-Identifier: Zlib */
 
 #ifndef GIRARA_TYPES_H
 #define GIRARA_TYPES_H
@@ -52,17 +52,6 @@ enum
   GIRARA_GOTO_END /**< Go to end of the line */
 };
 
-/**
- * Log levels
- */
-typedef enum girara_log_level_e
-{
-  GIRARA_DEBUG, /**> Debug messages */
-  GIRARA_INFO, /**> Information debug output */
-  GIRARA_WARNING, /**> Warning level */
-  GIRARA_ERROR /**> Error */
-} girara_log_level_t;
-
 /**
  * Mode identifier
  */
@@ -155,7 +144,7 @@ typedef enum girara_setting_type_e
  * @param data User data
  */
 typedef void (*girara_setting_callback_t)(girara_session_t* session,
-    const char* name, girara_setting_type_t type, void* value, void* data);
+    const char* name, girara_setting_type_t type, const void* value, void* data);
 
 /**
  * Definition of an argument of a shortcut or buffered command
